Article title - teedoc
Description: article description
Keywords: keyword1, keyword2

## teedoc

- Install
- Develop

- github
- 语言: English
  - 中文
  - English

- Search
  Keywords separated by space Loading, wait please ... Download error, please check network and refresh again Result from other docs Result from current doc

- Introduction to teedoc
- Install teedoc
- Start writing document
- Pay attention to when writing documents
- Plugin
  - Theme Plugin
  - Other plugins
- markdown syntax
- Jupyter syntax
- Deployment
  - Deploy to github
  - Use nginx to deploy to the server
  - Use CDN to accelerate website
- SEO (Optimize for Search Engines)
- Website using teedoc
- Common problem
- More
- More samples
  - Second-level subdirectory example
    - Sample three-level sub-directory
      - Article 1
    - Article 2
  - This is a external link

# Article title

Edit this page

Please read document at Official website: teedoc.neucrack.com or teedoc.github.io

And refer to source file of official site: github.com/teedoc/teedoc.github.io

Install teedoc

- Links
  - Build with teedoc
  - Copyright © 2021 Neucrack
  - Sitemap
- Source code
  - github
  - website source files

- *ICP备********号
- *公网安备***********号